==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRadioGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioGroupDescription } from "./WebRadioGroupDescription";
/**
 * @hidden
 */
var WebRadioGroupDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRadioGroupDescriptionMetadata, _super);
    function WebRadioGroupDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRadioGroupDescriptionMetadata.b = function (a) {
        if (WebRadioGroupDescriptionMetadata.a == null) {
            WebRadioGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRadioGroupDescriptionMetadata.c(WebRadioGroupDescriptionMetadata.a);
        }
        if (a.j(WebRadioGroupDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRadioGroupDescriptionMetadata.a);
    };
    WebRadioGroupDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RadioGroup");
        a.item("__tagNameWC", "String:igc-radio-group");
        a.item("Alignment", "ExportedType:string:RadioGroupAlignment");
        a.item("Alignment@names", "Vertical;Horizontal");
    };
    WebRadioGroupDescriptionMetadata.d = function (a) {
        WebRadioGroupDescriptionMetadata.b(a);
        a.aa("WebRadioGroup", function () { return new WebRadioGroupDescription(); });
        a.z("WebRadioGroup", WebRadioGroupDescriptionMetadata.a);
    };
    WebRadioGroupDescriptionMetadata.$t = markType(WebRadioGroupDescriptionMetadata, 'WebRadioGroupDescriptionMetadata');
    WebRadioGroupDescriptionMetadata.a = null;
    return WebRadioGroupDescriptionMetadata;
}(Base));
export { WebRadioGroupDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebRadioGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioGroupDescription } from "./WebRadioGroupDescription";
/**
 * @hidden
 */
var WebRadioGroupDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRadioGroupDescriptionMetadata, _super);
    function WebRadioGroupDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRadioGroupDescriptionMetadata.b = function (a) {
        if (WebRadioGroupDescriptionMetadata.a == null) {
            WebRadioGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRadioGroupDescriptionMetadata.c(WebRadioGroupDescriptionMetadata.a);
        }
        if (a.k(WebRadioGroupDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRadioGroupDescriptionMetadata.a);
    };
    WebRadioGroupDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RadioGroup");
        a.item("__tagNameWC", "String:igc-radio-group");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Alignment", "ExportedType:string:RadioGroupAlignment");
        a.item("Alignment@stringUnion", "WebComponents;React");
        a.item("Alignment@names", "Vertical;Horizontal");
    };
    WebRadioGroupDescriptionMetadata.d = function (a) {
        WebRadioGroupDescriptionMetadata.b(a);
        a.ac("WebRadioGroup", function () { return new WebRadioGroupDescription(); });
        a.ab("WebRadioGroup", WebRadioGroupDescriptionMetadata.a);
    };
    WebRadioGroupDescriptionMetadata.$t = markType(WebRadioGroupDescriptionMetadata, 'WebRadioGroupDescriptionMetadata');
    WebRadioGroupDescriptionMetadata.a = null;
    return WebRadioGroupDescriptionMetadata;
}(Base));
export { WebRadioGroupDescriptionMetadata };
